@@ -23,9 +23,10 @@ def test_service__load_universe__public():
 #     assert data_univ['base.object']
 
 
-# def test_service__layer_profile():
-#     sc = ServiceClient(service_url)
-#     sc.set_token('lx-FlBARh6kuhm0qPIIR7AAAAAAAAAAAAAAAAAAAAABsbvhtBDmszI_Ya8fqTM96Fde4YgAAAAD___9_/hfo2aZSR2Cl09Gxcm3zdDXEfr2I')
-#     # univ = sc.load_universe('18ce41cfb98e0c26d5f12797782dac68')
-#     profile = sc.get_layer_profile('6c6ef86d0439accc8fd86bc7ea4ccf7a')
-#     print(profile)
+def test_service__layer_profile():
+    sc = ServiceClient(service_url)
+    sc.set_token('AcTnSLTMXZeD3m9Rj8LfOVZCyGIAAAAA____fwIAYgAAADJwcm9maWxlL2U0ZjkwNTc2MzQzMjgzNWQ2Mjc0Y2NhNjQ0MzUxZjlkL2dldFRva2VuczB1bml2ZXJzZS9jNWZhY2JjOWRjYjljMzlhYzM0Yjk4OWE4ZTc1ZGU2YS9leHBvcnS5QQPEH11r1YaJrgAzRh01909Xyg')
+    # univ = sc.load_universe('18ce41cfb98e0c26d5f12797782dac68')
+    profile = sc.get_layer_profile('e4f905763432835d6274cca644351f9d')
+    assert profile
+    print(profile)
