@@ -302,7 +302,7 @@ def load_universe(universe_def: Union[bytes, str]) -> Union[Universe, None]:
         model = universe.get_model(mapping)
         if not model:
             continue
-        model._description = info['description']
+        model._description = info.get('description', '')
         model._type = info['type']
         model._object_id = info.get('object')
 
